#!/bin/bash

echo "



 \ \        /       |          |                              
  \ \  \   /  _  |  __|   __|  __ \   __  __ \    _  |  __ \ 
   \ \  \ /  (   |  |    (     | | |  |   |   |  (   |  |   | 
    \_/\_/  \__,_| \__| \___| _| |_| _|  _|  _| \__,_| _|  _| 
                                                              
        Linux Setup for Forensic Extractor for YouTube 


                        thewatchman.pro 
                            © 2023 



Before running this setup script, please perform the following actions:

1. Assign Execute (x) permissions to setup.sh: sudo chmod +x setup.sh
2. Run the setup.sh script: ./setup.sh





"

# Detect Linux distribution
if [ -f /etc/os-release ]; then
    . /etc/os-release
    distro="$ID"
elif [ -f /etc/lsb-release ]; then
    . /etc/lsb-release
    distro="$DISTRIB_ID"
else
    echo "Unsupported Linux distribution."
    exit 1
fi

echo "Detected Linux distribution: $distro"

# Check if ffmpeg is installed
if ! command -v ffmpeg &> /dev/null; then
    echo "FFmpeg not found, proceeding to install..."
    
    # Install required packages
    case "$distro" in
        "ubuntu"|"debian"|"parrot")
            sudo apt update -y
            sudo apt install -y ffmpeg
            sudo apt-get install -y python3.10
            sudo apt-get install -y python3-virtualenv
            sudo apt install -y python3-pip
            ;;
        "fedora"|"centos"|"rhel")
            sudo dnf -y install https://download1.rpmfusion.org/free/fedora/rpmfusion-free-release-$(rpm -E %fedora).noarch.rpm
            sudo dnf -y install https://download1.rpmfusion.org/nonfree/fedora/rpmfusion-nonfree-release-$(rpm -E %fedora).noar
            sudo dnf -y install ffmpeg
            sudo dnf -y install python3.10
            sudo dnf -y install python3-virtualenv
            sudo yum -y install pip
            ;;
        *)
            echo "Unsupported Linux distribution"
            exit 1
            ;;
    esac
fi

# Create Python virtual environment
echo "Setting up the Python3 virtual environment."
python_version=$(python3 --version | cut -d ' ' -f 2 | cut -d '.' -f 1,2)
python3 -m venv __WATCHMAN__

# Activate virtual environment
echo "Activating the Python3 virtual environment."
source __WATCHMAN__/bin/activate
sudo chmod +x forensic-extractor-youtube.py

# Install required Python packages
echo "Preparing to install required dependencies."

pip install --upgrade pip
pip install yt-dlp blake3 pytube colr
echo "Setup completed successfully."

echo "Launch the virtual environment in the terminal: source __WATCHMAN__/bin/activate"
echo "Execute the script: python forensic-extractor-youtube.py"